@@ -724,7 +724,7 @@ get_ticket_sync (GoaKerberosProvider *self,
           g_set_error (error,
                        GOA_ERROR,
                        GOA_ERROR_NOT_AUTHORIZED,
-                       _("Could not find saved credentials for principal `%s' in keyring"), identifier);
+                       _("Could not find saved credentials for principal ‘%s’ in keyring"), identifier);
       goto out;
     }
   else if (credentials != NULL)
@@ -737,7 +737,7 @@ get_ticket_sync (GoaKerberosProvider *self,
           g_set_error (error,
                        GOA_ERROR,
                        GOA_ERROR_NOT_AUTHORIZED,
-                       _("Did not find password for principal `%s' in credentials"),
+                       _("Did not find password for principal ‘%s’ in credentials"),
                        identifier);
           goto out;
         }
@@ -1726,6 +1726,8 @@ show_account (GoaProvider *provider,
   goa_util_add_account_info (grid, row++, object);
 
   goa_util_add_row_switch_from_keyfile_with_blurb (grid, row++, object,
+                                                   /* Translators: This is a label for a series of
+                                                    * options switches. For example: “Use for Mail”. */
                                                    _("Use for"),
                                                    "ticketing-disabled",
                                                    _("Network _Resources"));
